*********
Selenium
*********

For functional testing it's used `Selenium IDE <http://www.seleniumhq.org/projects/ide/>`_.

Installation
============
#. Install Firefox plugin `Selenium IDE plugin <http://www.seleniumhq.org/download/>`_

Running
=======
Follow `Selenium IDE instruction <http://www.seleniumhq.org/docs/02_selenium_ide.jsp#opening-the-ide>`_ to run test suites.

TestSuites
==========
- Chat_TestSuite.html: has all tests related to chat process like create, join, exit chat
- Page_TestSuite.html: holds all static pages tests like licence, privacy etc.
